@@ -1,4 +1,4 @@
-from osaft import WaveTypes, Yosioka1955
+from osaft import WaveType, Yosioka1955
 from osaft.tests.basetest_plotting import BaseTestPlotting
 
 
@@ -14,7 +14,7 @@ class BaseTestScattering(BaseTestPlotting):
         self.rho_s = 1e3
         self.rho_f = 1.5e3
         self.p_0 = 1e5
-        self.wave_type = WaveTypes.TRAVELLING
+        self.wave_type = WaveType.TRAVELLING
         self.position = self.c_f / self.f / 8
 
         self.N_max = 10
